@@ -197,8 +197,9 @@ class ProgressBar:
         self.char = char
         start = "["
         stop = ']'
-        bar = f"[" + " "*len + " ]"
+        bar = f"[" + " "*len + "]"
         self.pg = 0
+        self.chw = 0
         sys.stdout.write(u"\u001b[1000D"+bar)
         sys.stdout.flush()
     def fill(self, ms=10, sec=None):
@@ -212,7 +213,7 @@ class ProgressBar:
             #print((len-_))
             sleep(t)
             #char -= (_+1)
-            bar = "[" + (char*(self.chw+_+1)) +" "*(self.len-_)
+            bar = "[" + (char*(self.chw+_)) +" "*(self.len-_) + "]"
             sys.stdout.write(u"\u001b[1000D"+bar)
             sys.stdout.flush()
         print()
@@ -227,7 +228,7 @@ class ProgressBar:
         char = self.char
         self.pg += 1*step
         self.chw = step
-        bar = "[" + (char*(self.pg+1)) +" "*(self.len-self.pg) + "]"
+        bar = "[" + (char*(self.pg)) +" "*(self.len-self.pg) + "]"
         sys.stdout.write(u"\u001b[1000D"+bar)
         sys.stdout.flush()
         if self.pg == self.len:
